@@ -16,7 +16,7 @@
 #
 #******************************************************************************
 
-from struct import pack, unpack, unpack_from
+from struct import pack, unpack
 import re
 
 _TTF_MAC_HEADER = False
@@ -35,19 +35,19 @@ def sub32(x, y):
     xhi = x[0]
     ylo = y[1]
     yhi = y[0]
-    if (ylo > xlo):
+    if ylo > xlo:
         xlo += 1 << 16
         yhi += 1
     reslo = xlo - ylo
-    if (yhi > xhi):
+    if yhi > xhi:
         xhi += 1 << 16
     reshi = xhi - yhi
     reshi = reshi & 0xFFFF
-    return (reshi, reslo)
+    return reshi, reslo
 
 
 def calcChecksum(data):
-    if (len(data) % 4):
+    if len(data) % 4:
         data += "\0" * (4 - (len(data) % 4))
     hi = 0x0000
     lo = 0x0000
@@ -57,13 +57,13 @@ def calcChecksum(data):
         hi += lo >> 16
         lo = lo & 0xFFFF
         hi = hi & 0xFFFF
-    return (hi, lo)
+    return hi, lo
 
 
 class TTFontFile:
 
     def __init__(self):
-        self.maxStrLenRead = 200000     # Maximum size of glyf table to read in
+        self.maxStrLenRead = 200000     # Maximum size of glyph table to read in
                                         # as string (otherwise reads each glyph
                                         # from file)
 
@@ -80,11 +80,11 @@ class TTFontFile:
         self.descent = 0
         self.TTCFonts = {}
         self.version = version = self.read_ulong()
-        if (version == 0x4F54544F):
+        if version == 0x4F54544F:
             raise Exception("Postscript outlines are not supported")
-        if (version == 0x74746366):
+        if version == 0x74746366:
             raise Exception("ERROR - TrueType Fonts Collections not supported")
-        if (version not in (0x00010000, 0x74727565)):
+        if version not in (0x00010000, 0x74727565):
             raise Exception("Not a TrueType font: version=" + version)
         self.readTableDirectory()
         self.extractInfo()
@@ -107,7 +107,7 @@ class TTFontFile:
     def get_table_pos(self, tag):
         offset = self.tables[tag]['offset']
         length = self.tables[tag]['length']
-        return (offset, length)
+        return offset, length
 
     def seek(self, pos):
         self._pos = pos
@@ -131,13 +131,13 @@ class TTFontFile:
         self._pos += 2
         s = self.fh.read(2)
         a = (ord(s[0]) << 8) + ord(s[1])
-        if (a & (1 << 15)):
+        if a & (1 << 15):
             a = (a - (1 << 16))
         return a
 
     def unpack_short(self, s):
         a = (ord(s[0]) << 8) + ord(s[1])
-        if (a & (1 << 15)):
+        if a & (1 << 15):
             a = (a - (1 << 16))
         return a
 
@@ -164,7 +164,7 @@ class TTFontFile:
         return (ord(s[0]) * 16777216) + (ord(s[1]) << 16) + (ord(s[2]) << 8) + ord(s[3])  # 16777216  = 1<<24
 
     def pack_short(self, val):
-        if (val < 0):
+        if val < 0:
             val = abs(val)
             val = ~val
             val += 1
@@ -178,7 +178,7 @@ class TTFontFile:
         return self.splice(stream, offset, up)
 
     def _set_short(self, stream, offset, val):
-        if (val < 0):
+        if val < 0:
             val = abs(val)
             val = ~val
             val += 1
@@ -187,19 +187,19 @@ class TTFontFile:
 
     def get_chunk(self, pos, length):
         self.fh.seek(pos)
-        if (length < 1):
+        if length < 1:
             return ''
-        return (self.fh.read(length))
+        return self.fh.read(length)
 
     def get_table(self, tag):
         (pos, length) = self.get_table_pos(tag)
-        if (length == 0):
+        if length == 0:
             raise Exception('Truetype font (' + self.filename + '): error reading table: ' + tag)
         self.fh.seek(pos)
-        return (self.fh.read(length))
+        return self.fh.read(length)
 
     def add(self, tag, data):
-        if (tag == 'head'):
+        if tag == 'head':
             data = self.splice(data, 8, "\0\0\0\0")
         self.otables[tag] = data
 
@@ -217,7 +217,7 @@ class TTFontFile:
 
         name_offset = self.seek_table("name")
         format = self.read_ushort()
-        if (format != 0):
+        if format != 0:
             raise Exception("Unknown name table format " + format)
         numRecords = self.read_ushort()
         string_data_offset = name_offset + self.read_ushort()
@@ -231,63 +231,63 @@ class TTFontFile:
             nameId = self.read_ushort()
             length = self.read_ushort()
             offset = self.read_ushort()
-            if (nameId not in K):
+            if nameId not in K:
                 continue
             N = ''
-            if (platformId == 3 and encodingId == 1 and languageId == 0x409):  # Microsoft, Unicode, US English, PS Name
+            if platformId == 3 and encodingId == 1 and languageId == 0x409:  # Microsoft, Unicode, US English, PS Name
                 opos = self._pos
                 self.seek(string_data_offset + offset)
-                if (length % 2 != 0):
+                if length % 2 != 0:
                     raise Exception("PostScript name is UTF-16BE string of odd length")
                 length /= 2
                 N = ''
-                while (length > 0):
+                while length > 0:
                     char = self.read_ushort()
                     N += (chr(char))
                     length -= 1
                 self._pos = opos
                 self.seek(opos)
 
-            elif (platformId == 1 and encodingId == 0 and languageId == 0):  # Macintosh, Roman, English, PS Name
+            elif platformId == 1 and encodingId == 0 and languageId == 0:  # Macintosh, Roman, English, PS Name
                 opos = self._pos
                 N = self.get_chunk(string_data_offset + offset, length)
                 self._pos = opos
                 self.seek(opos)
 
-            if (N and names[nameId] == ''):
+            if N and names[nameId] == '':
                 names[nameId] = N
                 nameCount -= 1
-                if (nameCount == 0):
+                if nameCount == 0:
                     break
 
-        if (names[6]):
+        if names[6]:
             psName = names[6]
-        elif (names[4]):
+        elif names[4]:
             psName = re.sub(' ', '-', names[4])
-        elif (names[1]):
+        elif names[1]:
             psName = re.sub(' ', '-', names[1])
         else:
             psName = ''
-        if (not psName):
+        if not psName:
             raise Exception("Could not find PostScript font name")
         self.name = psName
-        if (names[1]):
+        if names[1]:
             self.familyName = names[1]
         else:
             self.familyName = psName
-        if (names[2]):
+        if names[2]:
             self.styleName = names[2]
         else:
             self.styleName = 'Regular'
-        if (names[4]):
+        if names[4]:
             self.fullName = names[4]
         else:
             self.fullName = psName
-        if (names[3]):
+        if names[3]:
             self.uniqueFontID = names[3]
         else:
             self.uniqueFontID = psName
-        if (names[6]):
+        if names[6]:
             self.fullName = names[6]
 
         #################/
@@ -306,14 +306,14 @@ class TTFontFile:
         self.skip(3 * 2)
         indexToLocFormat = self.read_ushort()
         glyphDataFormat = self.read_ushort()
-        if (glyphDataFormat != 0):
+        if glyphDataFormat != 0:
             raise Exception('Unknown glyph data format ' + glyphDataFormat)
 
         #################/
         # hhea metrics table
         #################/
         # ttf2t1 seems to use this value rather than the one in OS/2 - so put in for compatibility
-        if ("hhea" in self.tables):
+        if "hhea" in self.tables:
             self.seek_table("hhea")
             self.skip(4)
             hheaAscender = self.read_short()
@@ -324,16 +324,16 @@ class TTFontFile:
         #################/
         # OS/2 - OS/2 and Windows metrics table
         #################/
-        if ("OS/2" in self.tables):
+        if "OS/2" in self.tables:
             self.seek_table("OS/2")
             version = self.read_ushort()
             self.skip(2)
             usWeightClass = self.read_ushort()
             self.skip(2)
             fsType = self.read_ushort()
-            if (fsType == 0x0002 or (fsType & 0x0300) != 0):
-                raise Exception('ERROR - Font file ' + self.filename + ' cannot be embedded due to copyright restrictions.')
+            if fsType == 0x0002 or (fsType & 0x0300) != 0:
                 self.restrictedUse = True
+                raise Exception('ERROR - Font file ' + self.filename + ' cannot be embedded due to copyright restrictions.')
 
             self.skip(20)
             sF = self.read_short()
@@ -344,11 +344,11 @@ class TTFontFile:
             self.skip(26)
             sTypoAscender = self.read_short()
             sTypoDescender = self.read_short()
-            if (not self.ascent):
+            if not self.ascent:
                 self.ascent = (sTypoAscender * scale)
-            if (not self.descent):
+            if not self.descent:
                 self.descent = (sTypoDescender * scale)
-            if (version > 1):
+            if version > 1:
                 self.skip(16)
                 sCapHeight = self.read_short()
                 self.capHeight = (sCapHeight * scale)
@@ -356,9 +356,9 @@ class TTFontFile:
                 self.capHeight = self.ascent
         else:
             usWeightClass = 500
-            if (not self.ascent):
+            if not self.ascent:
                 self.ascent = (yMax * scale)
-            if (not self.descent):
+            if not self.descent:
                 self.descent = (yMin * scale)
             self.capHeight = self.ascent
         self.stemV = 50 + int(pow((usWeightClass / 65.0), 2))
@@ -375,11 +375,11 @@ class TTFontFile:
 
         self.flags = 4
 
-        if (self.italicAngle != 0):
+        if self.italicAngle != 0:
             self.flags = self.flags | 64
-        if (usWeightClass >= 600):
+        if usWeightClass >= 600:
             self.flags = self.flags | 262144
-        if (isFixedPitch):
+        if isFixedPitch:
             self.flags = self.flags | 1
 
         #################/
@@ -388,10 +388,10 @@ class TTFontFile:
         self.seek_table("hhea")
         self.skip(32)
         metricDataFormat = self.read_ushort()
-        if (metricDataFormat != 0):
-            raise Exception('Unknown horizontal metric data format '.metricDataFormat)
+        if metricDataFormat != 0:
+            raise Exception('Unknown horizontal metric data format ', metricDataFormat)
         numberOfHMetrics = self.read_ushort()
-        if (numberOfHMetrics == 0):
+        if numberOfHMetrics == 0:
             raise Exception('Number of horizontal metrics is 0')
 
         #################/
@@ -413,15 +413,15 @@ class TTFontFile:
             encodingID = self.read_ushort()
             offset = self.read_ulong()
             save_pos = self._pos
-            if ((platformID == 3 and encodingID == 1) or platformID == 0):  # Microsoft, Unicode
+            if (platformID == 3 and encodingID == 1) or platformID == 0:  # Microsoft, Unicode
                 format = self.get_ushort(cmap_offset + offset)
-                if (format == 4):
-                    if (not unicode_cmap_offset):
+                if format == 4:
+                    if not unicode_cmap_offset:
                         unicode_cmap_offset = cmap_offset + offset
                     break
             self.seek(save_pos)
 
-        if (not unicode_cmap_offset):
+        if not unicode_cmap_offset:
             raise Exception('Font (' + self.filename + ') does not have cmap for Unicode (platform 3, encoding 1, format 4, or platform 0, any encoding, format 4)')
 
         glyphToChar = {}
@@ -436,7 +436,6 @@ class TTFontFile:
 
 ############################################/
 ############################################/
-
     def makeSubset(self, file, subset):
         self.filename = file
         self.fh = open(file, 'rb')
@@ -466,7 +465,7 @@ class TTFontFile:
         self.seek_table("hhea")
         self.skip(32)
         metricDataFormat = self.read_ushort()
-        orignHmetrics = numberOfHMetrics = self.read_ushort()
+        originHmetrics = numberOfHMetrics = self.read_ushort()
 
         #################/
         # maxp - Maximum profile table
@@ -487,13 +486,13 @@ class TTFontFile:
             encodingID = self.read_ushort()
             offset = self.read_ulong()
             save_pos = self._pos
-            if ((platformID == 3 and encodingID == 1) or platformID == 0):  # Microsoft, Unicode
+            if (platformID == 3 and encodingID == 1) or platformID == 0:  # Microsoft, Unicode
                 format = self.get_ushort(cmap_offset + offset)
-                if (format == 4):
+                if format == 4:
                     unicode_cmap_offset = cmap_offset + offset
                     break
             self.seek(save_pos)
-        if (not unicode_cmap_offset):
+        if not unicode_cmap_offset:
             raise Exception('Font (' + self.filename + ') does not have cmap for Unicode (platform 3, encoding 1, format 4, or platform 0, any encoding, format 4)')
 
         glyphToChar = {}
@@ -515,7 +514,7 @@ class TTFontFile:
         subsetglyphs = [(0, 0)]     # special "sorted dict"!
         subsetCharToGlyph = {}
         for code in subset:
-            if (code in self.charToGlyph):
+            if code in self.charToGlyph:
                 if (self.charToGlyph[code], code) not in subsetglyphs:
                     subsetglyphs.append((self.charToGlyph[code], code))   # Old Glyph ID => Unicode
                 subsetCharToGlyph[code] = self.charToGlyph[code]    # Unicode to old GlyphID
@@ -550,7 +549,7 @@ class TTFontFile:
             self.add(tag, self.get_table(tag))
         tags = ['cvt ', 'fpgm', 'prep', 'gasp']
         for tag in tags:
-            if (tag in self.tables):
+            if tag in self.tables:
                 self.add(tag, self.get_table(tag))
 
         # post - PostScript
@@ -568,7 +567,7 @@ class TTFontFile:
         prevglidx = -1
         # for each character
         for cid, glidx in sorted(codeToGlyph.items()):
-            if (cid == (prevcid + 1) and glidx == (prevglidx + 1)):
+            if cid == (prevcid + 1) and glidx == (prevglidx + 1):
                 range_[rangeid].append(glidx)
             else:
                 # new range
@@ -582,7 +581,7 @@ class TTFontFile:
         segCount = len(range_) + 1    # + 1 Last segment has missing character 0xFFFF
         searchRange = 1
         entrySelector = 0
-        while (searchRange * 2 <= segCount):
+        while searchRange * 2 <= segCount:
             searchRange = searchRange * 2
             entrySelector = entrySelector + 1
 
@@ -643,7 +642,7 @@ class TTFontFile:
 
         # glyf - Glyph data
         (glyfOffset, glyfLength) = self.get_table_pos('glyf')
-        if (glyfLength < self.maxStrLenRead):
+        if glyfLength < self.maxStrLenRead:
             glyphData = self.get_table('glyf')
 
         offsets = []
@@ -669,7 +668,7 @@ class TTFontFile:
 
         for originalGlyphIdx, uni in subsetglyphs:
             # hmtx - Horizontal Metrics
-            hm = self.getHMetric(orignHmetrics, originalGlyphIdx)
+            hm = self.getHMetric(originHmetrics, originalGlyphIdx)
             hmtxstr += hm
 
             offsets.append(pos)
@@ -677,24 +676,24 @@ class TTFontFile:
                 glyphPos = self.glyphPos[originalGlyphIdx]
                 glyphLen = self.glyphPos[originalGlyphIdx + 1] - glyphPos
             except IndexError:
-                print "missing glyph %s" % (originalGlyphIdx)
+                print "missing glyph %s" % originalGlyphIdx
                 glyphLen = 0
 
-            if (glyfLength < self.maxStrLenRead):
+            if glyfLength < self.maxStrLenRead:
                 data = glyphData[glyphPos: glyphPos + glyphLen]
             else:
-                if (glyphLen > 0):
+                if glyphLen > 0:
                     data = self.get_chunk(glyfOffset + glyphPos, glyphLen)
                 else:
                     data = ''
 
-            if (glyphLen > 0):
+            if glyphLen > 0:
                 up = unpack(">H", data[0: 2])[0]
-            if (glyphLen > 2 and (up & (1 << 15))):     # If number of contours <= -1 i.e. composiste glyph
+            if glyphLen > 2 and (up & (1 << 15)):     # If number of contours <= -1 i.e. composiste glyph
                 pos_in_glyph = 10
                 flags = GF_MORE
                 nComponentElements = 0
-                while (flags & GF_MORE):
+                while flags & GF_MORE:
                     nComponentElements += 1    # number of glyphs referenced at top level
                     up = unpack(">H", data[pos_in_glyph: pos_in_glyph + 2])
                     flags = up[0]
@@ -707,22 +706,22 @@ class TTFontFile:
                         data = 0
                         print "missing glyph data %s" % glyphIdx
                     pos_in_glyph += 4
-                    if (flags & GF_WORDS):
+                    if flags & GF_WORDS:
                         pos_in_glyph += 4
                     else:
                         pos_in_glyph += 2
-                    if (flags & GF_SCALE):
+                    if flags & GF_SCALE:
                         pos_in_glyph += 2
-                    elif (flags & GF_XYSCALE):
+                    elif flags & GF_XYSCALE:
                         pos_in_glyph += 4
-                    elif (flags & GF_TWOBYTWO):
+                    elif flags & GF_TWOBYTWO:
                         pos_in_glyph += 8
 
                 maxComponentElements = max(maxComponentElements, nComponentElements)
 
             glyf += data
             pos += glyphLen
-            if (pos % 4 != 0):
+            if pos % 4 != 0:
                 padding = 4 - (pos % 4)
                 glyf += "\0" * padding
                 pos += padding
@@ -735,7 +734,7 @@ class TTFontFile:
 
         # loca - Index to location
         locastr = ''
-        if (((pos + 1) >> 1) > 0xFFFF):
+        if ((pos + 1) >> 1) > 0xFFFF:
             indexToLocFormat = 1        # long format
             for offset in offsets:
                 locastr += pack(">L", offset)
@@ -777,19 +776,19 @@ class TTFontFile:
         # &maxdepth, &depth, &points, &contours
         nonlocals['depth'] += 1
         nonlocals['maxdepth'] = max(nonlocals['maxdepth'], nonlocals['depth'])
-        if (len(self.glyphdata[originalGlyphIdx]['compGlyphs'])):
+        if len(self.glyphdata[originalGlyphIdx]['compGlyphs']):
             for glyphIdx in self.glyphdata[originalGlyphIdx]['compGlyphs']:
                 self.getGlyphData(glyphIdx, nonlocals)
 
-        elif ((self.glyphdata[originalGlyphIdx]['nContours'] > 0) and nonlocals['depth'] > 0):     # simple
+        elif (self.glyphdata[originalGlyphIdx]['nContours'] > 0) and nonlocals['depth'] > 0:     # simple
             contours += self.glyphdata[originalGlyphIdx]['nContours']
             points += self.glyphdata[originalGlyphIdx]['nPoints']
 
         nonlocals['depth'] -= 1
 
-
     #########################################
     # Recursively get composite glyphs
+    #########################################
     def getGlyphs(self, originalGlyphIdx, nonlocals):
         # &start, &glyphSet, &subsetglyphs)
 
@@ -798,36 +797,36 @@ class TTFontFile:
             glyphLen = self.glyphPos[originalGlyphIdx + 1] - glyphPos
         except IndexError:
             #raise Exception("missing glyph %s" % (originalGlyphIdx))
-            print "missing glyph %s" % (originalGlyphIdx)
+            print "missing glyph %s" % originalGlyphIdx
             return
 
-        if (not glyphLen):
+        if not glyphLen:
             return
 
         self.seek(nonlocals['start'] + glyphPos)
         numberOfContours = self.read_short()
-        if (numberOfContours < 0):
+        if numberOfContours < 0:
             self.skip(8)
             flags = GF_MORE
-            while (flags & GF_MORE):
+            while flags & GF_MORE:
                 flags = self.read_ushort()
                 glyphIdx = self.read_ushort()
-                if (glyphIdx not in nonlocals['glyphSet']):
+                if glyphIdx not in nonlocals['glyphSet']:
                     nonlocals['glyphSet'][glyphIdx] = len(nonlocals['subsetglyphs'])    # old glyphID to new glyphID
                     nonlocals['subsetglyphs'].append((glyphIdx, 1))
 
                 savepos = self.fh.tell()
                 self.getGlyphs(glyphIdx, nonlocals)
                 self.seek(savepos)
-                if (flags & GF_WORDS):
+                if flags & GF_WORDS:
                     self.skip(4)
                 else:
                     self.skip(2)
-                if (flags & GF_SCALE):
+                if flags & GF_SCALE:
                     self.skip(2)
-                elif (flags & GF_XYSCALE):
+                elif flags & GF_XYSCALE:
                     self.skip(4)
-                elif (flags & GF_TWOBYTWO):
+                elif flags & GF_TWOBYTWO:
                     self.skip(8)
 
     #########################################
@@ -837,32 +836,32 @@ class TTFontFile:
         aw = 0
         self.charWidths = [0] * 256 * 256 * 2
         nCharWidths = 0
-        if ((numberOfHMetrics * 4) < self.maxStrLenRead):
+        if (numberOfHMetrics * 4) < self.maxStrLenRead:
             data = self.get_chunk(start, (numberOfHMetrics * 4))
             arr = unpack(">" + "H" * (len(data) / 2), data)
         else:
             self.seek(start)
         for glyph in range(numberOfHMetrics):
-            if ((numberOfHMetrics * 4) < self.maxStrLenRead):
+            if (numberOfHMetrics * 4) < self.maxStrLenRead:
                 aw = arr[(glyph * 2)]  # PHP starts arrays from index 0!? +1
             else:
                 aw = self.read_ushort()
                 lsb = self.read_ushort()
 
-            if (glyph in glyphToChar or glyph == 0):
-                if (aw >= (1 << 15)):
+            if glyph in glyphToChar or glyph == 0:
+                if aw >= (1 << 15):
                     aw = 0     # 1.03 Some (arabic) fonts have -ve values for width
                     # although should be unsigned value - comes out as e.g. 65108 (intended -50)
-                if (glyph == 0):
+                if glyph == 0:
                     self.defaultWidth = scale * aw
                     continue
 
                 for char in glyphToChar[glyph]:
-                    if (char != 0 and char != 65535):
+                    if char != 0 and char != 65535:
                         w = int(round(scale * aw))
-                        if (w == 0):
+                        if w == 0:
                             w = 65535
-                        if (char < 196608):
+                        if char < 196608:
                             self.charWidths[char] = w
                             nCharWidths += 1
 
@@ -871,13 +870,13 @@ class TTFontFile:
         diff = numGlyphs - numberOfHMetrics
         for pos in range(diff):
             glyph = pos + numberOfHMetrics
-            if (glyph in glyphToChar):
+            if glyph in glyphToChar:
                 for char in glyphToChar[glyph]:
-                    if (char != 0 and char != 65535):
+                    if char != 0 and char != 65535:
                         w = int(round(scale * aw))
-                        if (w == 0):
+                        if w == 0:
                             w = 65535
-                        if (char < 196608):
+                        if char < 196608:
                             self.charWidths[char] = w
                             nCharWidths += 1
 
@@ -887,7 +886,7 @@ class TTFontFile:
 
     def getHMetric(self, numberOfHMetrics, gid):
         start = self.seek_table("hmtx")
-        if (gid < numberOfHMetrics):
+        if gid < numberOfHMetrics:
             self.seek(start + (gid * 4))
             hm = self.fh.read(4)
         else:
@@ -900,12 +899,12 @@ class TTFontFile:
     def getLOCA(self, indexToLocFormat, numGlyphs):
         start = self.seek_table('loca')
         self.glyphPos = []
-        if (indexToLocFormat == 0):
+        if indexToLocFormat == 0:
             data = self.get_chunk(start, (numGlyphs * 2) + 2)
             arr = unpack(">" + "H" * (len(data) / 2), data)
             for n in range(numGlyphs):
                 self.glyphPos.append((arr[n] * 2))  # n+1 !?
-        elif (indexToLocFormat == 1):
+        elif indexToLocFormat == 1:
             data = self.get_chunk(start, (numGlyphs * 4) + 4)
             arr = unpack(">" + "L" * (len(data) / 4), data)
             for n in range(numGlyphs):
@@ -941,37 +940,36 @@ class TTFontFile:
         for n in range(segCount):
             endpoint = (endCount[n] + 1)
             for unichar in range(startCount[n], endpoint, 1):
-                if (idRangeOffset[n] == 0):
+                if idRangeOffset[n] == 0:
                     glyph = (unichar + idDelta[n]) & 0xFFFF
                 else:
                     offset = (unichar - startCount[n]) * 2 + idRangeOffset[n]
                     offset = idRangeOffset_start + 2 * n + offset
-                    if (offset >= limit):
+                    if offset >= limit:
                         glyph = 0
                     else:
                         glyph = self.get_ushort(offset)
-                        if (glyph != 0):
+                        if glyph != 0:
                             glyph = (glyph + idDelta[n]) & 0xFFFF
                 charToGlyph[unichar] = glyph
-                if (unichar < 196608):
+                if unichar < 196608:
                     self.maxUniChar = max(unichar, self.maxUniChar)
                 glyphToChar.setdefault(glyph, []).append(unichar)
 
-
     # Put the TTF file together
     def endTTFile(self, stm):
         stm = ''
         numTables = len(self.otables)
         searchRange = 1
         entrySelector = 0
-        while (searchRange * 2 <= numTables):
+        while searchRange * 2 <= numTables:
             searchRange = searchRange * 2
             entrySelector = entrySelector + 1
         searchRange = searchRange * 16
         rangeShift = numTables * 16 - searchRange
 
         # Header
-        if (_TTF_MAC_HEADER):
+        if _TTF_MAC_HEADER:
             stm += (pack(">LHHHH", 0x74727565, numTables, searchRange, entrySelector, rangeShift))    # Mac
         else:
             stm += (pack(">LHHHH", 0x00010000, numTables, searchRange, entrySelector, rangeShift))    # Windows
@@ -982,7 +980,7 @@ class TTFontFile:
         offset = 12 + numTables * 16
         sorted_tables = sorted(tables.items())
         for tag, data in sorted_tables:
-            if (tag == 'head'):
+            if tag == 'head':
                 head_start = offset
             stm += tag
             checksum = calcChecksum(data)
